Struct LGroup Copy item path Source pub struct LGroup {
pub l: u32 ,
pub awr: f64 ,
pub apl: f64 ,
pub qx: f64 ,
pub lrx: i32 ,
pub resonances: Vec <Resonance >,
}Expand description Parameters grouped by orbital angular momentum L.
In ENDF File 2 (LRF=3, Reich-Moore), resonances are grouped by L-value.
Each L-group contains resonances with different J values.
Orbital angular momentum quantum number.
Atomic weight ratio for this group.
Channel scattering radius for this L (fm). 0.0 means use the global value.
Q-value for competitive width (eV). Only meaningful for BW formalisms
(LRF=1/2) where LRX=1; zero otherwise.
Reference: ENDF-6 Formats Manual 2.2.1.1, L-value CONT record (C2 field).
Competitive width flag. LRX=0: no competitive width; LRX=1: competitive
reaction exists (width = GT - GN - GG - GF). Only used in BW formalisms.
Reference: ENDF-6 Formats Manual 2.2.1.1, L-value CONT record (L2 field).
Individual resonances in this L-group.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Instruments this type with the provided [
Span], returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
Create a new
Policy that returns [
Action::Follow] only if
self and
other return
Action::Follow.
Read more Create a new
Policy that returns [
Action::Follow] if either
self or
other returns
Action::Follow.
Read more The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.