has_endf_evaluation_for

Function has_endf_evaluation_for 

pub fn has_endf_evaluation_for(z: u32, a: u32, library: EndfLibrary) -> bool
Whether the given library has an evaluation for (Z, A).

Library-aware counterpart to endf_mat::has_endf_evaluation — must be used by GUI availability indicators that depend on the currently selected library.