known_isotopes_for

Function known_isotopes_for 

pub fn known_isotopes_for(z: u32, library: EndfLibrary) -> Vec<u32>
All mass numbers with an evaluation for element Z in the given library.

Library-aware counterpart to endf_mat::known_isotopes (which is ENDF/B-VIII.0-only) — must be used wherever the GUI surfaces the set of selectable isotopes for the currently selected library, otherwise TENDL-2023-only isotopes (e.g. Fm-247) will be silently hidden, and Br will be incorrectly shown as available under CENDL-3.2.