sammy_to_resonance_data

Function sammy_to_resonance_data 

pub fn sammy_to_resonance_data(
    inp: &SammyInpConfig,
    par: &SammyParFile,
) -> Result<ResonanceData, SammyParseError>
Convert parsed SAMMY .par + .inp into a NEREIDS ResonanceData.

Groups resonances by spin group, maps each group to an LGroup using the spin group definitions from the .inp file.